==> mono_1.1.12.1.orig.tar.gz: mono-1.1.12.1/mcs/class/System.Web/System.Web.Util/DataSourceResolver.cs <==
//
// System.Web.Util.DataSourceResolver
//
// Authors:
//	Ben Maurer (bmaurer@novell.com)
//
// (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

//
// This is from
// _Developing Microsoft ASP.NET Server Controls and Components_ (Kothari, Datye)
//    Listing 20-3 "GetDataSource" (page 564)
//

using System.Collections;
using System.ComponentModel;

namespace System.Web.Util {
	class DataSourceResolver {
		private DataSourceResolver () {}

		public static IEnumerable ResolveDataSource (object o, string data_member) 
		{
			IEnumerable ds;

			ds = o as IEnumerable;
			if (ds != null)
				return ds;

			IListSource ls = o as IListSource;

			if (ls == null)
				return null;
			
			IList member_list = ls.GetList ();
			if (! ls.ContainsListCollection)
				return member_list;

			ITypedList tl = member_list as ITypedList;
			if (tl == null)
				return null;

			PropertyDescriptorCollection pd = tl.GetItemProperties (new PropertyDescriptor [0]);
		
			if (pd == null || pd.Count == 0)
				throw new Exception ("The selected data source did not contain any data members to bind to");
		
			PropertyDescriptor member_desc = data_member == "" ?
				pd [0] :
				pd.Find (data_member, true);

			if (member_desc != null)
				ds = member_desc.GetValue (member_list [0]) as IEnumerable;

			if (ds == null)
				throw new Exception ("A list corresponding to the selected DataMember was not found");

			return ds;
		}
	}
}

==> mono_1.2.4.orig.tar.gz: mono-1.2.4/mcs/class/System.Web/System.Web.Util/DataSourceResolver.cs <==
//
// System.Web.Util.DataSourceResolver
//
// Authors:
//	Ben Maurer (bmaurer@novell.com)
//
// (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

//
// This is from
// _Developing Microsoft ASP.NET Server Controls and Components_ (Kothari, Datye)
//    Listing 20-3 "GetDataSource" (page 564)
//

using System.Collections;
using System.ComponentModel;

namespace System.Web.Util {
	class DataSourceResolver {
		private DataSourceResolver () {}

		public static IEnumerable ResolveDataSource (object o, string data_member) 
		{
			IEnumerable ds;

			ds = o as IEnumerable;
			if (ds != null)
				return ds;

			IListSource ls = o as IListSource;

			if (ls == null)
				return null;
			
			IList member_list = ls.GetList ();
			if (! ls.ContainsListCollection)
				return member_list;

			ITypedList tl = member_list as ITypedList;
			if (tl == null)
				return null;

			PropertyDescriptorCollection pd = tl.GetItemProperties (new PropertyDescriptor [0]);
		
			if (pd == null || pd.Count == 0)
				throw new HttpException ("The selected data source did not contain any data members to bind to");
		
			PropertyDescriptor member_desc = data_member == "" ?
				pd [0] :
				pd.Find (data_member, true);

			if (member_desc != null)
				ds = member_desc.GetValue (member_list [0]) as IEnumerable;

			if (ds == null)
				throw new HttpException ("A list corresponding to the selected DataMember was not found");

			return ds;
		}
	}
}
